from .rdm_plot import show_rdm
from .mds_plot import mds, rdm_dimension_reduction
from .model_plot import plot_model_comparison
from .icon import Icon
from .icon import icons_from_folder
